use crate::ValueType;
use std::cell::RefCell;

/// Describes a function's signature.
pub struct Function {
	/// The type of value that the function returns.
	pub ret: ValueType,

	/// The argument type definitions of the function.
	pub args: RefCell<Vec<ValueType>>
}

impl Function {
	pub fn new() -> Function {
		Function {
			ret: ValueType::Void,
			args: RefCell::new(Vec::new())
		}
	}
}